@@ -16,7 +16,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw() ] );
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.8';
+our $VERSION = '0.9';
 
 =head1 NAME
 
@@ -379,9 +379,9 @@ http://mac-itunes.googlecode.com
 
 =head1 SVN INFO
 
-$Revision: 84 $
-$Date: 2010-01-20 21:21:16 -0800 (Wed, 20 Jan 2010) $
-$Author: drewgstephens $
+$Revision: 86 $
+$Date: 2010-05-30 20:45:18 -0700 (Sun, 30 May 2010) $
+$Author: drewgstephens@gmail.com $
 
 =head1 COPYRIGHT AND LICENSE
 
